import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'AsleepFilled20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M15 3h-.2a13.09 13.09 0 0 0 1.82 26h.49a13.08 13.08 0 0 0 10.71-5.56 1 1 0 0 0-.82-1.56 13.08 13.08 0 0 1-11.12-17.5A1 1 0 0 0 15 3z',
        },
      }),
      children,
    ]);
  },
};
