import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'ChartScatter24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: { d: 'M30 30H4a2 2 0 0 1-2-2V2h2v26h26z' },
      }),
      createElement('circle', { attrs: { cx: '10', cy: '22', r: '2' } }),
      createElement('circle', { attrs: { cx: '14', cy: '15', r: '2' } }),
      createElement('circle', { attrs: { cx: '22', cy: '15', r: '2' } }),
      createElement('circle', { attrs: { cx: '26', cy: '6', r: '2' } }),
      createElement('circle', { attrs: { cx: '14', cy: '8', r: '2' } }),
      children,
    ]);
  },
};
