import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'Checkmark20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '20',
      height: '20',
      viewBox: '0 0 20 20',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: { d: 'M8 13.2L3.6 8.8l-.9.9 4.4 4.4.9.9 8.5-8.5-.9-.9z' },
      }),
      createElement('path', {
        attrs: {
          d: 'M15.6 5.6L8 13.2 3.6 8.8l-.9.9 4.4 4.4.9.9 8.5-8.5-.9-.9z',
        },
      }),
      children,
    ]);
  },
};
