import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'Compass24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M16 4A12 12 0 1 1 4 16 12 12 0 0 1 16 4m0-2a14 14 0 1 0 14 14A14 14 0 0 0 16 2z',
        },
      }),
      createElement('path', {
        attrs: {
          d:
            'M23 10.41L21.59 9l-4.3 4.3a3 3 0 0 0-4 4L9 21.59 10.41 23l4.3-4.3a3 3 0 0 0 4-4zM17 16a1 1 0 1 1-1-1 1 1 0 0 1 1 1z',
        },
      }),
      createElement('circle', { attrs: { cx: '16', cy: '7.5', r: '1.5' } }),
      children,
    ]);
  },
};
