import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'DataVis_324',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M28 3a2.991 2.991 0 0 0-2.816 2h-3.326a3.98 3.98 0 0 0-7.716 0H9.858A3.992 3.992 0 1 0 5 9.858v4.284a3.98 3.98 0 0 0 0 7.716v3.326a3 3 0 1 0 2 0v-3.326a3.978 3.978 0 0 0 1.673-.903l3.364 1.682A2.963 2.963 0 0 0 12 23a3.012 3.012 0 1 0 .922-2.157l-3.148-1.574A3.95 3.95 0 0 0 10 18a3.996 3.996 0 0 0-3-3.858V9.858A3.995 3.995 0 0 0 9.858 7h4.284a3.937 3.937 0 0 0 4.782 2.882l1.811 3.17a3.045 3.045 0 1 0 1.733-.998L20.689 8.94A3.984 3.984 0 0 0 21.858 7h3.326A2.995 2.995 0 1 0 28 3zM8 18a2 2 0 1 1-2-2 2.002 2.002 0 0 1 2 2zM6 8a2 2 0 1 1 2-2 2.002 2.002 0 0 1-2 2zm10-2a2 2 0 1 1 2 2 2.002 2.002 0 0 1-2-2z',
        },
      }),
      children,
    ]);
  },
};
