import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'LetterXx24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M15 9h-2l-2 6-2-6H7l2.75 7L7 23h2l2-6 2 6h2l-2.76-7L15 9zm10 4h-2l-2 3.9-2-3.9h-2l2.91 5L17 23h2l2-3.8 2 3.8h2l-2.9-5 2.9-5z',
        },
      }),
      children,
    ]);
  },
};
