import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'NotSent20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M30 28.59L3.41 2 2 3.41l8 8-7.34 2.65a1 1 0 0 0 0 1.87l9.6 3.84 3.84 9.6a1 1 0 0 0 .9.63 1 1 0 0 0 .92-.66L20.6 22l8 8zM5.8 15l5.74-2 3.05 3-1.83 1.83zM17 26.2l-2.79-7L16 17.41l3 3.05zm-1.31-14.75l7.64-2.78-2.78 7.64 1.56 1.56 3.83-10.53a1 1 0 0 0-1.28-1.28L14.13 9.89z',
        },
      }),
      children,
    ]);
  },
};
