import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'Redo32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M9 15c-2.5 0-4 1.5-4 4s1.5 4 4 4h5v2H9c-3.5 0-6-2.5-6-6s2.5-6 6-6h16.2l-4-4 1.4-1.5L29 14l-6.4 6.4-1.4-1.4 4-4H9z',
        },
      }),
      children,
    ]);
  },
};
