import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'TextStrikethrough32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M28 15H17.956a39.769 39.769 0 0 0-1.338-.335c-2.808-.664-4.396-1.15-4.396-3.423a2.868 2.868 0 0 1 .787-2.145 4.789 4.789 0 0 1 3.013-1.09c2.83-.07 4.135.89 5.202 2.35l1.615-1.18a7.473 7.473 0 0 0-6.83-3.17 6.773 6.773 0 0 0-4.4 1.661 4.827 4.827 0 0 0-1.386 3.574A4.372 4.372 0 0 0 11.957 15H4v2h13.652c1.967.57 3.143 1.312 3.173 3.358a3.119 3.119 0 0 1-.862 2.393A5.824 5.824 0 0 1 16.243 24a6.634 6.634 0 0 1-5.145-2.691l-1.533 1.284A8.526 8.526 0 0 0 16.212 26h.1a7.67 7.67 0 0 0 5.048-1.819 5.078 5.078 0 0 0 1.465-3.853A4.952 4.952 0 0 0 21.675 17H28z',
        },
      }),
      children,
    ]);
  },
};
