import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'TextMining20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: { d: 'M18 28h8v2h-8zm0-4h12v2H18zm0-4h12v2H18z' },
      }),
      createElement('path', {
        attrs: {
          d:
            'M16.001 26.473H16L4.284 12.955 9.5 6h13l5.216 6.955-3.24 3.737 1.513 1.31 4.295-4.957L23.5 4h-15l-6.784 9.045 12.772 14.737 1.513-1.309z',
        },
      }),
      children,
    ]);
  },
};
