import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'Undo32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M23 15c2.5 0 4 1.5 4 4s-1.5 4-4 4h-5v2h5c3.5 0 6-2.5 6-6s-2.5-6-6-6H6.8l4-4-1.4-1.4L3 14l6.4 6.4 1.4-1.4-4-4H23z',
        },
      }),
      children,
    ]);
  },
};
