import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'WatsonHealthLaunchStudy_224',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('circle', { attrs: { cx: '23', cy: '7', r: '1' } }),
      createElement('path', {
        attrs: {
          d:
            'M26 4v6H6V4h20m0-2H6a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2zm-5.41 19.41L17 17.83V30h-2V17.83l-3.59 3.58L10 20l6-6 6 6-1.41 1.41z',
        },
      }),
      createElement('path', { attrs: { d: 'M8 6h12v2H8z' } }),
      children,
    ]);
  },
};
