import { getAttributes } from '@rocketsoftware/icon-helpers';

export default {
  name: 'WatsonHealthWindowOverlay32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = getAttributes({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M15 6h2v3h-2zm10 11h3v2h-3zM15 27h2v3h-2zM4 17h3v2H4zm2.774-6.814l1.414-1.414 2.122 2.122-1.415 1.414zm14.92.712l2.121-2.122 1.415 1.415-2.122 2.121zm-.004 14.189l1.414-1.415 2.121 2.122-1.414 1.414zm-14.913.723l2.12-2.121 1.415 1.414-2.121 2.121zM4 2h24v2H4zm12 22a6 6 0 1 0-6-6 6 6 0 0 0 6 6zm0-10v8a4 4 0 0 1 0-8z',
        },
      }),
      children,
    ]);
  },
};
