'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _20 = {
  name: 'QZ20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: { d: 'M20 9h-8v2h6l-6 10v2h8v-2h-6l6-10V9z' },
      }),
      children,
    ]);
  },
};

module.exports = _20;
