'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _16 = {
  name: 'Awake16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '16',
      height: '16',
      viewBox: '0 0 16 16',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M7.5 1h1v2.5h-1zm3.304 3.454l1.768-1.768.707.707-1.768 1.768zM12.5 7.5H15v1h-2.5zm-1.662 4.01l.707-.706 1.768 1.767-.707.707zM7.5 12.5h1V15h-1zm-4.778.11l1.768-1.77.707.707-1.768 1.768zM1 7.5h2.5v1H1zm1.688-4.07l.707-.706L5.163 4.49l-.707.707zM8 6c1.1 0 2 .9 2 2s-.9 2-2 2-2-.9-2-2 .9-2 2-2m0-1C6.3 5 5 6.3 5 8s1.3 3 3 3 3-1.3 3-3-1.3-3-3-3z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _16;
