'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _24 = {
  name: 'DataCheck24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: { d: 'M23 27.18l-2.59-2.59L19 26l4 4 7-7-1.41-1.41L23 27.18z' },
      }),
      createElement('circle', { attrs: { cx: '11', cy: '8', r: '1' } }),
      createElement('circle', { attrs: { cx: '11', cy: '16', r: '1' } }),
      createElement('circle', { attrs: { cx: '11', cy: '24', r: '1' } }),
      createElement('path', {
        attrs: {
          d:
            'M24 3H8a2 2 0 0 0-2 2v22a2 2 0 0 0 2 2h8v-2H8v-6h18V5a2 2 0 0 0-2-2zm0 16H8v-6h16zm0-8H8V5h16z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _24;
