'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _32 = {
  name: 'Diagram32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M13 30a11 11 0 0 1 0-22 1 1 0 0 1 1 1v9h9a1 1 0 0 1 1 1 11 11 0 0 1-11 11zm-1-19.94A9 9 0 1 0 21.94 20H14a2 2 0 0 1-2-2z',
        },
      }),
      createElement('path', {
        attrs: {
          d:
            'M28 14h-9a2 2 0 0 1-2-2V3a1 1 0 0 1 1-1 11 11 0 0 1 11 11 1 1 0 0 1-1 1zm-9-2h7.94A9 9 0 0 0 19 4.06z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _32;
