'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _24 = {
  name: 'IotConnect24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M30 19h-4v-4h-2v9H8V8h9V6h-4V2h-2v4H8a2.002 2.002 0 0 0-2 2v3H2v2h4v6H2v2h4v3a2.002 2.002 0 0 0 2 2h3v4h2v-4h6v4h2v-4h3a2.003 2.003 0 0 0 2-2v-3h4z',
        },
      }),
      createElement('path', {
        attrs: {
          d:
            'M26 2a4.004 4.004 0 0 0-4 4 3.956 3.956 0 0 0 .567 2.02L19.586 11H11v10h10v-8.586l2.98-2.98A3.955 3.955 0 0 0 26 10a4 4 0 0 0 0-8zm-7 17h-6v-6h6zm7-11a2 2 0 1 1 2-2 2.002 2.002 0 0 1-2 2z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _24;
