'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _24 = {
  name: 'MacShift24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M21 28H11a2 2 0 0 1-2-2V16H4a1 1 0 0 1-.92-.62 1 1 0 0 1 .21-1.09l12-12a1 1 0 0 1 1.42 0l12 12a1 1 0 0 1 .21 1.09A1 1 0 0 1 28 16h-5v10a2 2 0 0 1-2 2zM6.41 14H10a1 1 0 0 1 1 1v11h10V15a1 1 0 0 1 1-1h3.59L16 4.41z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _24;
