'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _16 = {
  name: 'PlayOutline16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '16',
      height: '16',
      viewBox: '0 0 16 16',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M8 2c3.3 0 6 2.7 6 6s-2.7 6-6 6-6-2.7-6-6 2.7-6 6-6m0-1C4.1 1 1 4.1 1 8s3.1 7 7 7 7-3.1 7-7-3.1-7-7-7z',
        },
      }),
      createElement('path', {
        attrs: {
          d:
            'M6 11.5c-.1 0-.2 0-.3-.1-.2-.1-.2-.3-.2-.4V5c0-.2.1-.3.2-.4.2-.1.3-.1.5 0l5.5 3c.3.1.4.4.2.6 0 .1-.1.2-.2.2l-5.5 3c0 .1-.1.1-.2.1zm.5-5.7v4.3l4-2.2-4-2.1z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _16;
