'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _24 = {
  name: 'Save24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '24',
      height: '24',
      viewBox: '0 0 24 24',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M20.8 7L17 3.2c-.1-.1-.3-.2-.5-.2h-12C3.7 3 3 3.7 3 4.5v15c0 .8.7 1.5 1.5 1.5h15c.8 0 1.5-.7 1.5-1.5v-12c0-.2-.1-.4-.2-.5zM9 4.5h6v3H9v-3zm6 15H9v-6h6v6zm1.5 0v-6c0-.8-.7-1.5-1.5-1.5H9c-.8 0-1.5.7-1.5 1.5v6h-3v-15h3v3C7.5 8.3 8.2 9 9 9h6c.8 0 1.5-.7 1.5-1.5V4.8l3 3v11.7h-3z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _24;
