'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _20 = {
  name: 'Sunset20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M12.556 30.005a3.953 3.953 0 0 1-.556-2 4 4 0 0 1 8 0 3.953 3.953 0 0 1-.556 2h2.207a6 6 0 1 0-11.302 0zm12.444-3h5v2h-5zm-3.313-6.101l3.506-3.506 1.414 1.414-3.506 3.506zM15 14.005h2v5h-2zm-9.606 4.808l1.415-1.414 3.505 3.506L8.9 22.319zM2 27.005h5v2H2z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _20;
