'use strict';

var iconHelpers = require('@rocketsoftware/icon-helpers');

var _20 = {
  name: 'Types20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render(createElement, context) {
    const { children, data, listeners, props } = context;
    const attrs = iconHelpers.getAttributes({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title,
      ...data.attrs,
    });
    const svgData = {
      attrs,
      on: listeners,
    };

    if (data.staticClass) {
      svgData.class = {
        [data.staticClass]: true,
      };
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [
      props.title && createElement('title', null, props.title),
      createElement('path', {
        attrs: {
          d:
            'M27 28h-8a1 1 0 0 1-.894-1.447l4-8a1.041 1.041 0 0 1 1.788 0l4 8A1 1 0 0 1 27 28zm-6.382-2h4.764L23 21.236zM14 19.415L12.586 18 9 21.587 5.414 18 4 19.415 7.586 23 4 26.586 5.414 28 9 24.414 12.586 28 14 26.586 10.414 23 14 19.415zM23 14a.997.997 0 0 1-.707-.293l-4-4a1 1 0 0 1 0-1.414l4-4a1 1 0 0 1 1.414 0l4 4a1 1 0 0 1 0 1.414l-4 4A.997.997 0 0 1 23 14zm-2.586-5L23 11.586 25.586 9 23 6.414zM9 14a5 5 0 1 1 5-5 5.006 5.006 0 0 1-5 5zm0-8a3 3 0 1 0 3 3 3.003 3.003 0 0 0-3-3z',
        },
      }),
      children,
    ]);
  },
};

module.exports = _20;
